@@ -16,11 +16,12 @@ Lindblad models module.
 """
 
 from typing import Tuple, Union, List, Optional
+from warnings import warn
 from scipy.sparse.csr import csr_matrix
 
 from qiskit import QiskitError
 from qiskit.quantum_info.operators import Operator
-from qiskit_dynamics.dispatch import Array
+from qiskit_dynamics.array import Array
 from qiskit_dynamics.type_utils import to_numeric_matrix_type
 from qiskit_dynamics.signals import Signal, SignalList
 from .generator_model import (
@@ -34,10 +35,17 @@ from .operator_collections import (
     DenseLindbladCollection,
     DenseVectorizedLindbladCollection,
     SparseLindbladCollection,
+    JAXSparseLindbladCollection,
     SparseVectorizedLindbladCollection,
+    JAXSparseVectorizedLindbladCollection,
 )
 from .rotating_frame import RotatingFrame
 
+try:
+    import jax
+except ImportError:
+    pass
+
 
 class LindbladModel(BaseGeneratorModel):
     r"""A model of a quantum system in terms of the Lindblad master equation.
@@ -45,41 +53,54 @@ class LindbladModel(BaseGeneratorModel):
     The Lindblad master equation models the evolution of a density matrix according to:
 
     .. math::
-        \dot{\rho}(t) = -i[H(t), \rho(t)] + \mathcal{D}(t)(\rho(t)),
 
-    where :math:`\mathcal{D}(t)` is the dissipator portion of the equation,
-    given by
+        \dot{\rho}(t) = -i[H(t), \rho(t)] + \mathcal{D}_0(\rho(t)) + \mathcal{D}(t)(\rho(t)),
+
+    where :math:`\mathcal{D}_0` is the static dissipator portion, and :math:`\mathcal{D}(t)` is the
+    time-dependent dissipator portion of the equation, given by
 
     .. math::
+
+        \mathcal{D}_0(\rho(t)) = \sum_j N_j \rho N_j^\dagger
+                                      - \frac{1}{2} \{N_j^\dagger N_j, \rho\},
+
+    and
+
+    .. math::
+
         \mathcal{D}(t)(\rho(t)) = \sum_j \gamma_j(t) L_j \rho L_j^\dagger
                                   - \frac{1}{2} \{L_j^\dagger L_j, \rho\},
 
-    with :math:`[\cdot, \cdot]` and :math:`\{\cdot, \cdot\}` the
-    matrix commutator and anti-commutator, respectively. In the above:
+    respectively. In the above:
 
+        - :math:`[\cdot, \cdot]` and :math:`\{\cdot, \cdot\}`
+          respectively denote the matrix commutator and anti-commutator,
         - :math:`H(t)` denotes the Hamiltonian,
-        - :math:`L_j` denotes the :math:`j^{th}` dissipator, or Lindblad,
-          operator, and
+        - :math:`N_j` denotes the operators appearing in the static dissipator,
+        - :math:`L_j` denotes the operators appearing in the time-dpendent portion of the
+          dissipator, and
         - :math:`\gamma_j(t)` denotes the signal corresponding to the
-          :math:`j^{th}` Lindblad operator.
+          :math:`j^{th}` time-dependent dissipator operator.
 
     Instantiating an instance of :class:`~qiskit_dynamics.models.LindbladModel`
     requires specifying the above decomposition:
 
     .. code-block:: python
 
-        lindblad_model = LindbladModel(static_hamiltonian=static_hamiltonian,
-                                       hamiltonian_operators=hamiltonian_operators,
-                                       hamiltonian_signals=hamiltonian_signals,
-                                       static_dissipators=static_dissipators,
-                                       dissipator_operators=dissipator_operators,
-                                       dissipator_signals=dissipator_signals)
+        lindblad_model = LindbladModel(
+            static_hamiltonian=static_hamiltonian,
+            hamiltonian_operators=hamiltonian_operators,
+            hamiltonian_signals=hamiltonian_signals,
+            static_dissipators=static_dissipators,
+            dissipator_operators=dissipator_operators,
+            dissipator_signals=dissipator_signals
+        )
 
     where the arguments ``hamiltonian_operators``, ``hamiltonian_signals``, and
     ``static_hamiltonian`` are for the Hamiltonian decomposition as in
     :class:`~qiskit_dynamics.models.HamiltonianModel`,
-    and the ``dissipator_operators`` correspond to the :math:`L_j`, and the ``dissipator_signals``
-    the :math:`g_j(t)`, which default to the constant ``1.``.
+    and the ``static_dissipators`` correspond to the :math:`N_j`, the ``dissipator_operators``
+    to the :math:`L_j`, and the ``dissipator_signals`` the :math:`\gamma_j(t)`.
     """
 
     def __init__(
@@ -110,7 +131,7 @@ class LindbladModel(BaseGeneratorModel):
                             already in the frame basis.
             in_frame_basis: Whether to represent the model in the basis in which the rotating
                             frame operator is diagonalized.
-            evaluation_mode: Evaluation mode to use. See ``LindbladModel.evaluation_mode``
+            evaluation_mode: Evaluation mode to use. Call ``help(LindbladModel.evaluation_mode)``
                              for more details.
             validate: If True check input hamiltonian_operators and static_hamiltonian are
                       Hermitian.
@@ -173,7 +194,7 @@ class LindbladModel(BaseGeneratorModel):
             static_dissipators: List of dissipators with coefficient 1.
             dissipator_operators: List of dissipators with time-dependent coefficients.
             dissipator_signals: List time-dependent coefficients for dissipator_operators.
-            evaluation_mode: Evaluation mode. See LindbladModel.evaluation_mode
+            evaluation_mode: Evaluation mode. Call ``help(LindbladModel.evaluation_mode)``
                 for more information.
 
         Returns:
@@ -243,7 +264,11 @@ class LindbladModel(BaseGeneratorModel):
                 raise QiskitError("Hamiltonian signals specified in unaccepted format.")
 
             # verify signal length is same as operators
-            if len(hamiltonian_signals) != len(self.hamiltonian_operators):
+            if isinstance(self.hamiltonian_operators, list):
+                len_hamiltonian_operators = len(self.hamiltonian_operators)
+            else:
+                len_hamiltonian_operators = self.hamiltonian_operators.shape[0]
+            if len(hamiltonian_signals) != len_hamiltonian_operators:
                 raise QiskitError(
                     "Hamiltonian signals need to have the same length as Hamiltonian operators."
                 )
@@ -265,7 +290,11 @@ class LindbladModel(BaseGeneratorModel):
                 raise QiskitError("Dissipator signals specified in unaccepted format.")
 
             # verify signal length is same as operators
-            if len(dissipator_signals) != len(self.dissipator_operators):
+            if isinstance(self.dissipator_operators, list):
+                len_dissipator_operators = len(self.dissipator_operators)
+            else:
+                len_dissipator_operators = self.dissipator_operators.shape[0]
+            if len(dissipator_signals) != len_dissipator_operators:
                 raise QiskitError(
                     "Dissipator signals need to have the same length as dissipator operators."
                 )
@@ -397,15 +426,17 @@ class LindbladModel(BaseGeneratorModel):
 
         Available options:
 
-            - 'dense': Stores Hamiltonian and dissipator terms as dense
-               Array types.
-            - 'dense_vectorized': Stores the Hamiltonian and dissipator
-              terms as (dim^2,dim^2) matrices that acts on a vectorized
-              density matrix by left-multiplication. Allows for direct evaluate generator.
-            - 'sparse': Like dense, but stores Hamiltonian components with
-              `csr_matrix` types. Outputs will be dense if a 2d frame operator is
-              used. Not compatible with jax.
-            - `sparse_vectorized': Like dense_vectorized, but stores everything as csr_matrices.
+         * 'dense': Stores Hamiltonian and dissipator terms as dense Array types.
+         * 'dense_vectorized': Stores the Hamiltonian and dissipator
+            terms as :math:`(dim^2,dim^2)` matrices that acts on a vectorized
+            density matrix by left-multiplication. Allows for direct evaluate generator.
+         * 'sparse': Like dense, but matrices stored in sparse format. If the default Array backend
+            is JAX, uses JAX BCOO sparse arrays, otherwise uses scipy
+            :class:`csr_matrix` sparse type.
+         * `sparse_vectorized`: Like dense_vectorized, but matrices stored in sparse format.
+            If the default Array backend is JAX, uses JAX BCOO sparse arrays, otherwise uses scipy
+            :class:`csr_matrix` sparse type. Note that
+            JAX sparse mode is only recommended for use on CPU.
         """
         return self._evaluation_mode
 
@@ -631,14 +662,32 @@ def construct_lindblad_operator_collection(
         NotImplementedError: if evaluation_mode is not one of the above
         supported evaluation modes.
     """
+
+    # raise warning if sparse mode set with JAX not on cpu
+    if (
+        Array.default_backend() == "jax"
+        and "sparse" in evaluation_mode
+        and jax.default_backend() != "cpu"
+    ):
+        warn(
+            """Using sparse mode with JAX is primarily recommended for use on CPU.""",
+            stacklevel=2,
+        )
+
     if evaluation_mode == "dense":
         CollectionClass = DenseLindbladCollection
     elif evaluation_mode == "sparse":
-        CollectionClass = SparseLindbladCollection
+        if Array.default_backend() == "jax":
+            CollectionClass = JAXSparseLindbladCollection
+        else:
+            CollectionClass = SparseLindbladCollection
     elif evaluation_mode == "dense_vectorized":
         CollectionClass = DenseVectorizedLindbladCollection
     elif evaluation_mode == "sparse_vectorized":
-        CollectionClass = SparseVectorizedLindbladCollection
+        if Array.default_backend() == "jax":
+            CollectionClass = JAXSparseVectorizedLindbladCollection
+        else:
+            CollectionClass = SparseVectorizedLindbladCollection
     else:
         raise NotImplementedError(
             "Evaluation mode '"
