@@ -22,8 +22,16 @@ from scipy.sparse import issparse, csr_matrix
 from qiskit import QiskitError
 from qiskit.quantum_info.operators import Operator
 from qiskit.quantum_info.operators.predicates import is_hermitian_matrix
-from qiskit_dynamics.dispatch import Array
-from qiskit_dynamics.type_utils import to_array, to_numeric_matrix_type
+from qiskit_dynamics.array import Array
+from qiskit_dynamics.type_utils import to_array, to_BCOO, to_numeric_matrix_type
+
+try:
+    import jax.numpy as jnp
+    from jax.experimental import sparse as jsparse
+
+    jsparse_matmul = jsparse.sparsify(jnp.matmul)
+except ImportError:
+    pass
 
 
 class RotatingFrame:
@@ -166,38 +174,64 @@ class RotatingFrame:
         return self.frame_basis @ y
 
     def operator_into_frame_basis(
-        self, op: Union[Operator, List[Operator], Array, csr_matrix, None]
+        self,
+        op: Union[Operator, List[Operator], Array, csr_matrix, None],
+        convert_type: bool = True,
     ) -> Array:
         r"""Take an operator into the frame basis, i.e. return
         ``self.frame_basis_adjoint @ A @ self.frame_basis``
 
         Args:
             op: The operator or array of operators.
+            convert_type: Whether or not to initially convert ``op`` into an expected type.
+                          Should only be set to ``False`` in situations in which it is gauranteed
+                          that ``op`` is a handled input type.
         Returns:
             Array: The operator in the frame basis.
         """
-        op = to_numeric_matrix_type(op)
+        if convert_type:
+            op = to_numeric_matrix_type(op)
+
         if self.frame_basis is None or op is None:
             return op
-        # parentheses are necessary for sparse op evaluation
-        return self.frame_basis_adjoint @ (op @ self.frame_basis)
+
+        if isinstance(op, list):
+            return [self.operator_into_frame_basis(x, convert_type=False) for x in op]
+        elif type(op).__name__ == "BCOO":
+            return self.frame_basis_adjoint @ jsparse_matmul(op, self.frame_basis.data)
+        else:
+            # parentheses are necessary for sparse op evaluation
+            return self.frame_basis_adjoint @ (op @ self.frame_basis)
 
     def operator_out_of_frame_basis(
-        self, op: Union[Operator, List[Operator], Array, csr_matrix, None]
+        self,
+        op: Union[Operator, List[Operator], Array, csr_matrix, None],
+        convert_type: bool = True,
     ) -> Array:
         r"""Take an operator out of the frame basis, i.e. return
         ``self.frame_basis @ to_array(op) @ self.frame_basis_adjoint``.
 
         Args:
             op: The operator or array of operators.
+            convert_type: Whether or not to initially convert ``op`` into an expected type.
+                          Should only be set to ``False`` in situations in which it is gauranteed
+                          that ``op`` is a handled input type.
         Returns:
             Array: The operator in the frame basis.
         """
-        op = to_numeric_matrix_type(op)
+        if convert_type:
+            op = to_numeric_matrix_type(op)
+
         if self.frame_basis is None or op is None:
             return op
-        # parentheses are necessary for sparse op evaluation
-        return self.frame_basis @ (op @ self.frame_basis_adjoint)
+
+        if isinstance(op, list):
+            return [self.operator_out_of_frame_basis(x, convert_type=False) for x in op]
+        elif type(op).__name__ == "BCOO":
+            return self.frame_basis @ jsparse_matmul(op, self.frame_basis_adjoint.data)
+        else:
+            # parentheses are necessary for sparse op evaluation
+            return self.frame_basis @ (op @ self.frame_basis_adjoint)
 
     def state_into_frame(
         self,
@@ -313,8 +347,12 @@ class RotatingFrame:
             if op_to_add_in_fb is None:
                 return operator
             else:
-                if issparse(operator) and op_to_add_in_fb is not None:
-                    op_to_add_in_fb = csr_matrix(op_to_add_in_fb)
+                if op_to_add_in_fb is not None:
+                    if issparse(operator):
+                        op_to_add_in_fb = csr_matrix(op_to_add_in_fb)
+                    elif type(operator).__name__ == "BCOO":
+                        op_to_add_in_fb = to_BCOO(op_to_add_in_fb)
+
                 return operator + op_to_add_in_fb
 
         out = operator
@@ -330,12 +368,17 @@ class RotatingFrame:
         frame_mat = exp_freq.conj().reshape(self.dim, 1) * exp_freq
         if issparse(out):
             out = out.multiply(frame_mat)
+        elif type(out).__name__ == "BCOO":
+            out = out * frame_mat.data
         else:
             out = frame_mat * out
 
         if op_to_add_in_fb is not None:
-            if issparse(out) and op_to_add_in_fb is not None:
+            if issparse(out):
                 op_to_add_in_fb = csr_matrix(op_to_add_in_fb)
+            elif type(out).__name__ == "BCOO":
+                op_to_add_in_fb = to_BCOO(op_to_add_in_fb)
+
             out = out + op_to_add_in_fb
 
         # if output is requested to not be in the frame basis, convert it
@@ -344,7 +387,7 @@ class RotatingFrame:
 
         if vectorized_operators:
             # If a vectorized output is required, reshape correctly
-            out = out.reshape(out.shape[:-2] + (self.dim ** 2,), order="F")
+            out = out.reshape(out.shape[:-2] + (self.dim**2,), order="F")
             if len(out.shape) == 2:
                 out = out.T
 
@@ -596,7 +639,6 @@ def _is_herm_or_anti_herm(mat: Array, atol: Optional[float] = 1e-10, rtol: Optio
     if mat.backend == "jax":
 
         from jax.lax import cond
-        import jax.numpy as jnp
 
         mat = mat.data
 
@@ -636,7 +678,4 @@ def _is_herm_or_anti_herm(mat: Array, atol: Optional[float] = 1e-10, rtol: Optio
                 return mat
 
         # raise error if execution has made it this far
-        raise QiskitError(
-            """frame_operator must be either a Hermitian or
-                           anti-Hermitian matrix."""
-        )
+        raise QiskitError("""frame_operator must be either a Hermitian or anti-Hermitian matrix.""")
